@@ -12,9 +12,9 @@ BIBLE_JS = """
                 block: 'start'
             });
             // Optional: Highlight the verse temporarily
-            element.classList.add('bg-yellow-200', 'ring-2', 'ring-yellow-500', 'shadow-lg');
+            element.classList.add('bg-green-200', 'ring-2', 'ring-green-500', 'shadow-lg');
             setTimeout(() => {
-                element.classList.remove('bg-yellow-200', 'ring-2', 'ring-yellow-500', 'shadow-lg');
+                element.classList.remove('bg-green-200', 'ring-2', 'ring-green-500', 'shadow-lg');
             }, 2000); // Remove highlight after 2 seconds
         } else {
             console.error(`Element with ID '${verseId}' not found.`);
