@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 from nicegui import ui
-from biblemategui import config, BIBLEMATEGUI_APP_DIR, USER_DEFAULT_SETTINGS
+from biblemategui import config, BIBLEMATEGUI_DATA, BIBLEMATEGUI_APP_DIR, USER_DEFAULT_SETTINGS
 from biblemategui.pages.home import *
 from biblemategui.js.tooltip import TOOLTIP_JS
 from biblemategui.css.tooltip import get_tooltip_css
@@ -8,19 +8,22 @@ import os
 
 def get_tooltip_data(word):
     """Fetch tooltip data from database"""
+    import apsw, json
     result = None
+    db = os.path.join(BIBLEMATEGUI_DATA, "morphology.sqlite")
     with apsw.Connection(db) as connn:
-        query = "SELECT * FROM morphology WHERE WordID=?"
+        query = "SELECT * FROM morphology WHERE WordID=?" if word.startswith("wh") else "SELECT * FROM morphology WHERE WordID=? and Book > 39"
         cursor = connn.cursor()
-        cursor.execute(query, (word,))
-        result = cursor.fetchone()
-
-    """CREATE TABLE morphology (WordID INT, ClauseID INT, Book INT, Chapter INT, Verse INT, Word TEXT, LexicalEntry TEXT, MorphologyCode TEXT, Morphology TEXT, Lexeme TEXT, Transliteration TEXT, Pronunciation TEXT, Interlinear TEXT, Translation TEXT, Gloss TEXT)"""
-    
+        cursor.execute(query, (int(word[2:]),))
+        result = cursor.fetchone()    
     if result:
         wordID, clauseID, book, chapter, verse, word, lexicalEntry, morphologyCode, morphology, lexeme, transliteration, pronunciation, interlinear, translation, gloss = result
-        links = json.loads(links_json)
-        return {'description': interlinear, 'links': ""}
+        description = f'''<{'heb' if word.startswith("wh") else 'grk'}>{word}</{'heb' if word.startswith("wh") else 'grk'}> | <{'heb' if word.startswith("wh") else 'grk'}>{lexeme}</{'heb' if word.startswith("wh") else 'grk'}>
+{morphology}
+Interlinear: {interlinear}
+Translation: {translation}'''
+        #links = json.loads(links_json)
+        return {'description': description, 'links': ""}
     return None
 
 # API endpoint for tooltip data
