@@ -27,6 +27,9 @@ def original_discourse(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, **
     content = content.replace("<br<", "<br><")
     content = content.replace("<heb> </heb>", "<heb>&nbsp;</heb>")
 
+    # add tooltip
+    content = re.sub('(<heb id=")(.*?)"(.*?)class="', r'\1\2" data-word="\2" \3class="tooltip-word ', content)
+
     # add new tags
     content = content.replace("</vid> ", "</vid> <txt>")
     content = content.replace("<div class='bhsa'>", "</txt><div class='bhsa'>")
@@ -44,7 +47,7 @@ def original_discourse(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, **
         ui.add_head_html(f"""
         <style>
             /* Main container for the Bible text - ensures RTL flow for verses */
-            .bible-text {{
+            .bible-text-heb {{
                 direction: ltr;
                 font-family: sans-serif;
                 padding: 0px;
@@ -82,7 +85,7 @@ def original_discourse(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, **
         ui.add_head_html(f"""
         <style>
             /* Main container for the Bible text - LTR flow for Greek */
-            .bible-text {{
+            .bible-text-grk {{
                 direction: ltr;
                 font-family: sans-serif;
                 padding: 0px;
@@ -124,7 +127,7 @@ def original_discourse(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, **
 
     # Render the HTML inside a styled container
     # REMEMBER: sanitize=False is required to keep your onclick/onmouseover attributes
-    ui.html(f'<div class="bible-text">{content}</div>', sanitize=False).classes(f'w-full pb-[70vh] {(tab1+"_chapter") if area == 1 else (tab2+"_chapter")}')
+    ui.html(f'''<div class="bible-text-{'heb' if "</heb>" in content else 'grk'}">{content}</div>''', sanitize=False).classes(f'w-full pb-[70vh] {(tab1+"_chapter") if area == 1 else (tab2+"_chapter")}')
 
     # After the page is built and ready, run our JavaScript
     if (not area == 1) and tab1 and tab2:
