@@ -42,7 +42,7 @@ def original_reader(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, **_):
         ui.add_head_html(f"""
         <style>
             /* Main container for the Bible text - ensures RTL flow for verses */
-            .bible-text {{
+            .bible-text-heb {{
                 direction: rtl;
                 font-family: sans-serif;
                 padding: 0px;
@@ -80,7 +80,7 @@ def original_reader(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, **_):
         ui.add_head_html(f"""
         <style>
             /* Main container for the Bible text - LTR flow for Greek */
-            .bible-text {{
+            .bible-text-grk {{
                 direction: ltr;
                 font-family: sans-serif;
                 padding: 0px;
@@ -123,7 +123,7 @@ def original_reader(gui=None, b=1, c=1, v=1, area=1, tab1=None, tab2=None, **_):
 
     # Render the HTML inside a styled container
     # REMEMBER: sanitize=False is required to keep your onclick/onmouseover attributes
-    ui.html(f'<div class="bible-text">{content}</div>', sanitize=False).classes(f'w-full pb-[70vh] {(tab1+"_chapter") if area == 1 else (tab2+"_chapter")}')
+    ui.html(f'''<div class="bible-text-{'heb' if "</heb>" in content else 'grk'}">{content}</div>''', sanitize=False).classes(f'w-full pb-[70vh] {(tab1+"_chapter") if area == 1 else (tab2+"_chapter")}')
 
     # After the page is built and ready, run our JavaScript
     if (not area == 1) and tab1 and tab2:
